* ============================================================== *
* Equality of Opportunity for Sexual and Gender Minorities 2024
* Code written by Omar Alburqueque, and reviewed by Paola Ballon
* Contact: oalburquequechav@worldbank.org
* < 1. EQOSOGI database ensambling >
* ============================================================== *

clear all
set more off

* directory macros
global input_ "$eqosogi_userpath\Reproducibility package\inputs"
global output_ "$eqosogi_userpath\Reproducibility package\outputs"

cd "$input_"

global countries "Algeria Argentina Armenia Bangladesh Bhutan Brazil Cambodia Cameroon Canada Chile China Costa_Rica Djibouti Ecuador Egypt Ethiopia Fiji France Georgia Germany Ghana Guinea_Bissau Guyana Haiti Honduras India Indonesia Iraq Israel Ivory_Coast Jamaica Japan Jordan Kenya Korea Kosovo Kyrgyz_Republic Lebanon Mauritius Mexico Mongolia Morocco Mozambique Nepal New_Zealand Nigeria Norway Pakistan Papua_New_Guinea Philippines Serbia South_Africa Spain Sri_Lanka Sudan Tanzania Thailand Timor_Leste Tunisia Türkiye Ukraine Uruguay Vietnam Zimbabwe"

foreach z in $countries{
	import excel using "$input_\coding sheets\Coding Sheet_`z'.xlsx", clear
	drop if _n>=222

	rename A qtext // question or item
	rename B resp // response

	keep qtext resp // the relevant information is contained in these variables

	gen question = substr(qtext, 1, strpos(qtext, " ") - 1) // retrieve the question code
	replace resp = subinstr(resp," ","",.) // some responses include a regular space

	* We only keep the items that include a response (Yes/No questions)
	gen t1 = ustrtrim(qtext) // temporary variable with deleted blank spaces for qtext
	replace t1 = subinstr(qtext," ","",.) // delete regular spaces 
	gen t2 = substr(t1,-8,8) // relevant questions/indicators include a (Yes/No) text at the end
	drop if t2!="(Yes/No)" // We delete the items with no response
	drop t1 t2 qtext

	order question resp

	* Original indicators are in the form 1.2a, but in Stata we need something like 1_2a
	gen t1 = substr(question, -1, 1)
	gen t2 = length(question) - 1
	replace question = substr(question, 1, t2) if t1=="."
	drop t1 t2
	replace question = subinstr(question, ".", "_", .)

	* Finally we just arrange data into a row vector with 167 columns (one for each question/indicator) 
	levelsof question, local(list_question) // macro for list of all questions/indicators
	gen id = _n // we generate a counter variable for reshaping data from long to wide format
	sort question
	reshape wide resp, i(id) j(question) string // reshape
	drop id

	* Questions/indicators will begin with a "q", e.g. q1_4a refers to indicator 1.4a
	foreach x of local list_question{
		rename resp`x' q`x'
	}
	collapse (firstnm) q*

	* We add the country name before saving the data file
	gen country = "`z'"
	order country q*
	
	di "country `z'"

	rename q5_15_b q5_15b
	rename q5_15_c q5_15c
	
	* We apply a correction for section 6.7
	if ("`z'"=="Armenia" | "`z'"=="Bhutan" | "`z'"=="Cambodia" | "`z'"=="Georgia" | "`z'"=="Kyrgyz_Republic"){
		rename q6_7_1 q6_7_a
		rename q6_7_2 q6_7_b
		rename q6_7_3 q6_7_c
		rename q6_7_4 q6_7_d
		rename q6_7_5 q6_7_e
		rename q6_7_6 q6_7_f
		rename q6_7_7 q6_7_g
		rename q6_7_8 q6_7_h
		rename q6_7_9 q6_7_i
		rename q6_7_10 q6_7_j
	}

	save "$output_\EQOSOGI_file_`z'.dta", replace
}
	
* ------------ *
* Data merging *
* ------------ *

local i = 0
foreach z in $countries{
	local i = `i' + 1
	if (`i'==1){
		use "$output_\EQOSOGI_file_`z'.dta", clear
	}
	else{
		append using "$output_\EQOSOGI_file_`z'.dta"
	}
	erase "$output_\EQOSOGI_file_`z'.dta"
}

* --------------- *
* Data refinement *
* --------------- *

* We will not use indicators in section 6.7
drop q6_7*

* Some "Yes/No" responses are written differently
d q*, varlist
local indicators = r(varlist)
foreach x of local indicators{
	replace `x' = "No" if `x'=="NO" | `x'=="no"
	replace `x' = "Yes" if `x'=="YES" | `x'=="yes"
}
* Special case: Indicator q5_6 in Jordan
replace q5_6 = "No" if country=="Jordan"
* Special case: Indicator q4_6a in Tanzania
replace q4_6a = "Yes" if country=="Tanzania"

* For some countries, indicators q4_5a, q4_5b, q4_5c are "N/A". They should be equivalent to "N/A" whenever corresponding indicators q4_4a, q4_4b, and q4_4c are "No".
replace q4_5a = "N/A" if q4_4a=="No"
replace q4_5b = "N/A" if q4_4b=="No"
replace q4_5c = "N/A" if q4_4c=="No"

* Changes in section 4.1: laws in accessing social protection
* 4.1.3 Social protection or others (e. g. benefits related to unemployment, pension, disability, transport, low-income families)?
foreach x in a b c{
	gen nq4_1_3`x' = "No"
	replace nq4_1_3`x' = "Yes" if q4_1_3`x'=="Yes" | q4_1_4`x'=="Yes" | q4_1_5`x'=="Yes" | q4_1_6`x'=="Yes" | q4_1_7`x'=="Yes"
	drop q4_1_3`x' q4_1_4`x' q4_1_5`x' q4_1_6`x' q4_1_7`x'
	rename nq4_1_3`x' q4_1_3`x'
}

* Changes in section 6.5: 
* 6.5.1 Police officers (Yes/No)     
* 6.5.2 Prosecutors (Yes/No) OR 6.5.3 Judges (Yes/No)      
* 6.5.4 Social workers (Yes/No)    
* 6.5.5 Paramedics/Doctors (Yes/No)        
* Not scored: 6.5.6 Others? (Yes/No)
gen nq6_5_2 = "No"
replace nq6_5_2 = "Yes" if (q6_5_2=="Yes" | q6_5_3=="Yes")
drop q6_5_2 q6_5_3 q6_5_6
rename nq6_5_2 q6_5_2
rename q6_5_4 q6_5_3
rename q6_5_5 q6_5_4

* Changes in section 6.6
* 6.6.1. Legal assistance (including asylum applications and completing court forms)? (Yes/No)         
* 6.6.2. Shelter/housing? (Yes/No)            
* 6.6.3. Forensics or medical examinations? (Yes/No) OR 6.6.4. Medical certificates? (Yes/No)  
* Not scored: 6.6.5. Others? (Yes/No)
gen nq6_6_3 = "No"
replace nq6_6_3 = "Yes" if (q6_6_3=="Yes" | q6_6_4=="Yes")
drop q6_6_3 q6_6_4 q6_6_5
rename nq6_6_3 q6_6_3

save "$output_\eqosogi_database_qualitative.dta", replace

* ------------- *
* Scoring guide *
* ------------- *

* List of indicators that requires the following recoding: 0 for "Yes", 1 for "No"
global recode_0yes_1no "q1_1a q1_1b q1_1c q1_2 q1_4a q1_4b q1_4c q1_6 q1_7 q2_8 q3_12 q4_5a q4_5b q4_5c q4_6a q4_6b q4_6c q4_7a q4_7b q4_7c q4_10a q4_10b q4_11 q4_13 q4_14 q5_5a q5_5b q5_5c q5_15a q5_15b q5_15c"

foreach x in $recode_0yes_1no{
	replace `x' = "0" if `x'=="Yes"
	replace `x' = "1" if `x'=="No"
}

* List of indicators that requires the following recoding: 1 for "Yes", 0 for "No"
global recode_1yes_0no "q1_3 q1_5 q2_1a q2_1b q2_1c q2_2a q2_2b q2_2c q2_3a q2_3b q2_3c q2_4 q2_5 q2_6 q2_7 q3_1_1a q3_1_1b q3_1_1c q3_1_2a q3_1_2b q3_1_2c q3_2_1a q3_2_1b q3_2_1c q3_2_2a q3_2_2b q3_2_2c q3_3a q3_3b q3_3c q3_4a q3_4b q3_4c q3_5a q3_5b q3_5c q3_6_1a q3_6_1b q3_6_1c q3_6_2a q3_6_2b q3_6_2c q3_7a q3_7b q3_7c q3_8_1 q3_8_2 q3_9 q3_10 q3_11 q4_1_1a q4_1_1b q4_1_1c q4_1_2a q4_1_2b q4_1_2c q4_1_3a q4_1_3b q4_1_3c q4_2 q4_3a q4_3b q4_3c q4_4a q4_4b q4_4c q4_8a q4_8b q4_8c q4_9a q4_9b q4_9c q4_12 q5_1 q5_2 q5_3 q5_4a q5_4b q5_4c q5_6 q5_7 q5_8 q5_9 q5_10 q5_11 q5_12 q5_13 q5_14 q5_16a q5_16b q5_16c q6_1_1a q6_1_1b q6_1_1c q6_2_2a q6_2_2b q6_2_2c q6_3_3a q6_3_3b q6_3_3c q6_4_4a q6_4_4b q6_4_4c q6_5_1 q6_5_2 q6_5_3 q6_5_4 q6_6_1 q6_6_2 q6_6_3"

foreach x in $recode_1yes_0no{
	replace `x' = "1" if `x'=="Yes"
	replace `x' = "0" if `x'=="No"
}

* Special recoding for N/A alternatives
foreach x in q1_3 q4_5a q4_5b q4_5c q4_7a q4_7b q4_7c{
	replace `x' = "0" if `x'=="N/A"
}

* -------------------------------------------------------- *
* Changes in indicators (according to LBG, T and I groups) *
* -------------------------------------------------------- *

** Decriminalization
rename q1_1a lgb_q1_1a
rename q1_1b t_q1_1b
rename q1_1c i_q1_1c
rename q1_2 lgb_q1_2
rename q1_3 lgb_q1_3
rename q1_4a lgb_q1_4a
rename q1_4b t_q1_4b
rename q1_4c i_q1_4c
rename q1_5 t_q1_5
clonevar i_q1_5 = t_q1_5 // this indicators works with T and I
drop q1_6
rename q1_7 t_q1_6

** AccEdu
rename q2_1a lgb_q2_1a
rename q2_1b t_q2_1b
rename q2_1c i_q2_1c
rename q2_2a lgb_q2_2a
rename q2_2b t_q2_2b
rename q2_2c i_q2_2c
rename q2_3a lgb_q2_3a
rename q2_3b t_q2_3b
rename q2_3c i_q2_3c
rename q2_4 lgb_q2_4
clonevar t_q2_4 = lgb_q2_4 // this indicator works with LGB, T and I
clonevar i_q2_4 = lgb_q2_4 // this indicator works with LGB, T and I
rename q2_5 lgb_q2_5
clonevar t_q2_5 = lgb_q2_5 // this indicator works with LGB, T and I
clonevar i_q2_5 = lgb_q2_5 // this indicator works with LGB, T and I
rename q2_6 lgb_q2_6
clonevar t_q2_6 = lgb_q2_6 // this indicator works with LGB, T and I
clonevar i_q2_6 = lgb_q2_6 // this indicator works with LGB, T and I
rename q2_7 lgb_q2_7
clonevar t_q2_7 = lgb_q2_7 // this indicator works with LGB, T and I
clonevar i_q2_7 = lgb_q2_7 // this indicator works with LGB, T and I
rename q2_8 t_q2_8

** AccLab
rename q3_1_1a lgb_q3_1_1a
rename q3_1_1b t_q3_1_1b
rename q3_1_1c i_q3_1_1c
rename q3_1_2a lgb_q3_1_2a
rename q3_1_2b t_q3_1_2b
rename q3_1_2c i_q3_1_2c
rename q3_2_1a lgb_q3_2_1a
rename q3_2_1b t_q3_2_1b
rename q3_2_1c i_q3_2_1c
rename q3_2_2a lgb_q3_2_2a
rename q3_2_2b t_q3_2_2b
rename q3_2_2c i_q3_2_2c
rename q3_3a lgb_q3_3a
rename q3_3b t_q3_3b
rename q3_3c i_q3_3c
rename q3_4a lgb_q3_4a
rename q3_4b t_q3_4b
rename q3_4c i_q3_4c
rename q3_5a lgb_q3_5a
rename q3_5b t_q3_5b
rename q3_5c i_q3_5c
rename q3_6_1a lgb_q3_6_1a
rename q3_6_1b t_q3_6_1b
rename q3_6_1c i_q3_6_1c
rename q3_6_2a lgb_q3_6_2a
rename q3_6_2b t_q3_6_2b
rename q3_6_2c i_q3_6_2c
rename q3_7a lgb_q3_7a
rename q3_7b t_q3_7b
rename q3_7c i_q3_7c
rename q3_8_1 lgb_q3_8_1
rename q3_8_2 lgb_q3_8_2
rename q3_11 t_q3_9
clonevar i_q3_9 = t_q3_9 // this indicator works with T and I
rename q3_12 t_q3_10

** Acc_PServ
rename q4_1_1a lgb_q4_1_1a
rename q4_1_1b t_q4_1_1b
rename q4_1_1c i_q4_1_1c
rename q4_1_2a lgb_q4_1_2a
rename q4_1_2b t_q4_1_2b
rename q4_1_2c i_q4_1_2c
rename q4_1_3a lgb_q4_1_3a
rename q4_1_3b t_q4_1_3b
rename q4_1_3c i_q4_1_3c
rename q4_2 lgb_q4_2
rename q4_3a lgb_q4_3a
rename q4_3b t_q4_3b
rename q4_3c i_q4_3c
rename q4_4a lgb_q4_4a
rename q4_4b t_q4_4b
rename q4_4c i_q4_4c
rename q4_5a lgb_q4_5a
rename q4_5b t_q4_5b
rename q4_5c i_q4_5c
rename q4_6a lgb_q4_6a
rename q4_6b t_q4_6b
rename q4_6c i_q4_6c
rename q4_7a lgb_q4_7a
rename q4_7b t_q4_7b
rename q4_7c i_q4_7c
rename q4_8a lgb_q4_8a
rename q4_8b t_q4_8b
rename q4_8c i_q4_8c
rename q4_9a lgb_q4_9a
rename q4_9b t_q4_9b
rename q4_9c i_q4_9c
rename q4_10a i_q4_10a
rename q4_10b i_q4_10b
drop q4_11
rename q5_12 i_q4_11
rename q4_12 t_q4_12
clonevar i_q4_12 = t_q4_12 // this indicator works with T and I
rename q5_6 t_q4_13
drop q4_13
rename q4_14 lgb_q4_14
clonevar t_q4_14 = lgb_q4_14 // this indicator works with LGB, T and I
clonevar i_q4_14 = lgb_q4_14 // this indicator works with LGB, T and I

** CivPol
rename q5_1 lgb_q5_1
clonevar t_q5_1 = lgb_q5_1 // this indicator works with LGB, T and I
clonevar i_q5_1 = lgb_q5_1 // this indicator works with LGB, T and I
rename q5_2 lgb_q5_2
clonevar t_q5_2 = lgb_q5_2 // this indicator works with LGB, T and I
clonevar i_q5_2 = lgb_q5_2 // this indicator works with LGB, T and I
rename q5_3 lgb_q5_3
clonevar t_q5_3 = lgb_q5_3 // this indicator works with LGB, T and I
clonevar i_q5_3 = lgb_q5_3 // this indicator works with LGB, T and I
rename q5_4a lgb_q5_4a
rename q5_4b t_q5_4b
rename q5_4c i_q5_4c
rename q5_5a lgb_q5_5a
rename q5_5b t_q5_5b
rename q5_5c i_q5_5c
rename q5_7 lgb_q5_6
rename q5_8 lgb_q5_7
rename q3_9 lgb_q5_8
rename q3_10 lgb_q5_9
rename q5_9 lgb_q5_10
rename q5_10 lgb_q5_11
rename q5_11 lgb_q5_12
rename q5_13 i_q5_13
rename q5_14 lgb_q5_14
clonevar t_q5_14 = lgb_q5_14 // this indicator works with LGB and T
rename q5_15a lgb_q5_15a
rename q5_15b t_q5_15b
rename q5_15c i_q5_15c
rename q5_16a lgb_q5_16a
rename q5_16b t_q5_16b
rename q5_16c i_q5_16c

** ProtHate
rename q6_1_1a lgb_q6_1_1a
rename q6_1_1b t_q6_1_1b
rename q6_1_1c i_q6_1_1c
rename q6_2_2a lgb_q6_2_2a
rename q6_2_2b t_q6_2_2b
rename q6_2_2c i_q6_2_2c
rename q6_3_3a lgb_q6_3_3a
rename q6_3_3b t_q6_3_3b
rename q6_3_3c i_q6_3_3c
rename q6_4_4a lgb_q6_4_4a
rename q6_4_4b t_q6_4_4b
rename q6_4_4c i_q6_4_4c
rename q6_5_1 lgb_q6_5_1
clonevar t_q6_5_1 = lgb_q6_5_1
clonevar i_q6_5_1 = lgb_q6_5_1
rename q6_5_2 lgb_q6_5_2
clonevar t_q6_5_2 = lgb_q6_5_2
clonevar i_q6_5_2 = lgb_q6_5_2
rename q6_5_3 lgb_q6_5_3
clonevar t_q6_5_3 = lgb_q6_5_3
clonevar i_q6_5_3 = lgb_q6_5_3
rename q6_5_4 lgb_q6_5_4
clonevar t_q6_5_4 = lgb_q6_5_4
clonevar i_q6_5_4 = lgb_q6_5_4
rename q6_6_1 lgb_q6_6_1
clonevar t_q6_6_1 = lgb_q6_6_1
clonevar i_q6_6_1 = lgb_q6_6_1
rename q6_6_2 lgb_q6_6_2
clonevar t_q6_6_2 = lgb_q6_6_2
clonevar i_q6_6_2 = lgb_q6_6_2
rename q6_6_3 lgb_q6_6_3
clonevar t_q6_6_3 = lgb_q6_6_3
clonevar i_q6_6_3 = lgb_q6_6_3

* -------------------------------------------- *
* Convert string to numeric for all indicators *
* -------------------------------------------- *

destring lgb_* t_* i_*, replace

* --------------------------- *
* Additional data corrections *
* --------------------------- *

* Pakistan
replace lgb_q2_7 = 0 if country=="Pakistan"
* Uruguay
replace lgb_q6_5_2 = 1 if country=="Uruguay"
replace t_q6_5_2 = 1 if country=="Uruguay"
* Chile
replace i_q1_5 = 0 if country=="Chile"
* Spain
replace i_q1_5 = 0 if country=="Spain"
replace i_q6_5_1 = 0 if country=="Spain"
replace lgb_q6_5_4 = 0 if country=="Spain"
replace i_q6_5_4 = 0 if country=="Spain"
* New Zealand
replace t_q2_7 = 0 if country=="New_Zealand"
replace i_q2_7 = 0 if country=="New_Zealand"
* Ecuador
replace t_q2_7 = 0 if country=="Ecuador"
replace i_q2_7 = 0 if country=="Ecuador"
replace i_q6_6_1 = 0 if country=="Ecuador"
* Mexico
replace t_q2_7 = 0 if country=="Mexico"
replace i_q2_7 = 0 if country=="Mexico"
* Germany
replace i_q2_4 = 0 if country=="Germany"
replace t_q2_7 = 0 if country=="Germany"
replace i_q2_7 = 0 if country=="Germany"
* Serbia
replace i_q6_5_2 = 0 if country=="Serbia"
* Argentina
replace t_q6_6_1 = 0 if country=="Argentina"
replace i_q6_6_1 = 0 if country=="Argentina"
replace t_q6_6_2 = 0 if country=="Argentina"
replace i_q6_6_2 = 0 if country=="Argentina"
replace t_q6_6_3 = 0 if country=="Argentina"
replace i_q6_6_3 = 0 if country=="Argentina"
replace i_q4_10b = 1 if country=="Argentina"
* Norway
replace i_q2_7 = 0 if country=="Norway"
replace i_q6_5_1 = 0 if country=="Norway"
* South Africa
replace t_q2_7 = 0 if country=="South_Africa"
replace i_q2_7 = 0 if country=="South_Africa"
* Bhutan
replace t_q2_8 = 1 if country=="Bhutan"
replace t_q3_10 = 1 if country=="Bhutan"
* India
replace i_q4_10a = 1 if country=="India"
replace i_q4_10b = 1 if country=="India"
* Sri Lanka
replace t_q3_10 = 1 if country=="Sri_Lanka"
* Egypt, Arab Rep.
replace t_q1_6 = 1 if country=="Egypt"
* Jordan
replace t_q1_1b = 0 if country=="Jordan"

* ------------------------------------------------- *
* EQOSOGI scores for each group (one mean approach) *
* ------------------------------------------------- *

egen eqosogi_lgb_om = rowmean(lgb_*)
egen eqosogi_t_om = rowmean(t_*)
egen eqosogi_i_om = rowmean(i_*)

* ---------------------------------- *
* Cross dimensional and group scores *
* ---------------------------------- *

foreach x in lgb t i{
	forvalues t = 1/6{
		egen dim_`t'_`x' = rowmean(`x'_q`t'*)
	}
}

* ---------------------------------------------------- *
* EQOSOGI scores for each group (double mean approach) *
* ---------------------------------------------------- *

egen eqosogi_lgb_dm = rowmean(dim_*_lgb)
egen eqosogi_t_dm = rowmean(dim_*_t)
egen eqosogi_i_dm = rowmean(dim_*_i)

* ------------------------------- *
* Overall score (both approaches) *
* ------------------------------- *

* descriptive stats by indicator
global d1 "lgb_q1_1a t_q1_1b i_q1_1c lgb_q1_2 lgb_q1_3 lgb_q1_4a t_q1_4b i_q1_4c t_q1_5 t_q1_6"
global d2 "lgb_q2_1a t_q2_1b i_q2_1c lgb_q2_2a t_q2_2b i_q2_2c lgb_q2_3a t_q2_3b i_q2_3c lgb_q2_4 lgb_q2_5 lgb_q2_6 lgb_q2_7 t_q2_8"
global d3 "lgb_q3_1_1a t_q3_1_1b i_q3_1_1c lgb_q3_1_2a t_q3_1_2b i_q3_1_2c lgb_q3_2_1a t_q3_2_1b i_q3_2_1c lgb_q3_2_2a t_q3_2_2b i_q3_2_2c lgb_q3_3a t_q3_3b i_q3_3c lgb_q3_4a t_q3_4b i_q3_4c lgb_q3_5a t_q3_5b i_q3_5c lgb_q3_6_1a t_q3_6_1b i_q3_6_1c lgb_q3_6_2a t_q3_6_2b i_q3_6_2c lgb_q3_7a t_q3_7b i_q3_7c lgb_q3_8_1 lgb_q3_8_2 t_q3_9 t_q3_10"
global d4 "lgb_q4_1_1a t_q4_1_1b i_q4_1_1c lgb_q4_1_2a t_q4_1_2b i_q4_1_2c lgb_q4_1_3a t_q4_1_3b i_q4_1_3c lgb_q4_2 lgb_q4_3a t_q4_3b i_q4_3c lgb_q4_4a t_q4_4b i_q4_4c lgb_q4_5a t_q4_5b i_q4_5c lgb_q4_6a t_q4_6b i_q4_6c lgb_q4_7a t_q4_7b i_q4_7c lgb_q4_8a t_q4_8b i_q4_8c lgb_q4_9a t_q4_9b i_q4_9c i_q4_10a i_q4_10b i_q4_11 t_q4_12 t_q4_13 lgb_q4_14"
global d5 "lgb_q5_1 lgb_q5_2 lgb_q5_3 lgb_q5_4a t_q5_4b i_q5_4c lgb_q5_5a t_q5_5b i_q5_5c lgb_q5_6 lgb_q5_7 lgb_q5_8 lgb_q5_9 lgb_q5_10 lgb_q5_11 lgb_q5_12 i_q5_13 lgb_q5_14 lgb_q5_15a t_q5_15b i_q5_15c lgb_q5_16a t_q5_16b i_q5_16c"
global d6 "lgb_q6_1_1a t_q6_1_1b i_q6_1_1c lgb_q6_2_2a t_q6_2_2b i_q6_2_2c lgb_q6_3_3a t_q6_3_3b i_q6_3_3c lgb_q6_4_4a t_q6_4_4b i_q6_4_4c lgb_q6_5_1 lgb_q6_5_2 lgb_q6_5_3 lgb_q6_5_4 lgb_q6_6_1 lgb_q6_6_2 lgb_q6_6_3"

* generating overall eqosogi score (one mean approach)
egen eqosogi_score_om = rowmean($d1 $d2 $d3 $d4 $d5 $d6)
forvalues t = 1/6{
	egen eqosogi_dim`t' = rowmean(${d`t'})
}

* generating overall eqosogi score (double mean approach)
egen eqosogi_score_dm = rowmean(eqosogi_dim*)

* ---------------------------- *
* Attaching country level data * 
* ---------------------------- *

* Country label corrections
replace country = "Costa Rica" if country=="Costa_Rica"
replace country = "Côte d’Ivoire" if country=="Ivory_Coast"
replace country = "Egypt, Arab Rep." if country=="Egypt"
replace country = "Guinea-Bissau" if country=="Guinea_Bissau"
replace country = "South Africa" if country=="South_Africa"
replace country = "Kyrgyz Republic" if country=="Kyrgyz_Republic"
replace country = "Korea, Rep." if country=="Korea"
replace country = "New Zealand" if country=="New_Zealand"
replace country = "Papua New Guinea" if country=="Papua_New_Guinea"
replace country = "Sri Lanka" if country=="Sri_Lanka"
replace country = "Timor-Leste" if country=="Timor_Leste"

* Attaching country data

preserve

import excel using "$input_\EQOSOGI 2_List of Countries_FY24 Classification.xlsx", firstrow clear
drop if _n>64
rename Economy country
rename Code countrycode
rename RegionDEC region_dec
rename Region region
rename IncomegroupFY24 incomegroup_fy24
rename FCSFY24 fcs_fy24
rename Lendingcategory lending_cat
rename Populationsize pop_size
rename Legaltraditionsoftheworld legal_trad
rename Levelofinclusiveness level_inclusive
rename Datacollector data_collect
format country %20s
save "temp.dta", replace

restore

merge 1:1 country using "temp.dta"
keep if _merge==3
drop _merge
erase "temp.dta"

format country %20s

global order_d1 "lgb_q1_1a t_q1_1b i_q1_1c lgb_q1_2 lgb_q1_3 lgb_q1_4a t_q1_4b i_q1_4c t_q1_5 i_q1_5 t_q1_6"
global order_d2 "lgb_q2_1a t_q2_1b i_q2_1c lgb_q2_2a t_q2_2b i_q2_2c lgb_q2_3a t_q2_3b i_q2_3c lgb_q2_4 t_q2_4 i_q2_4 lgb_q2_5 t_q2_5 i_q2_5 lgb_q2_6 t_q2_6 i_q2_6 lgb_q2_7 t_q2_7 i_q2_7 t_q2_8"
global order_d3 "lgb_q3_1_1a t_q3_1_1b i_q3_1_1c lgb_q3_1_2a t_q3_1_2b i_q3_1_2c lgb_q3_2_1a t_q3_2_1b i_q3_2_1c lgb_q3_2_2a t_q3_2_2b i_q3_2_2c lgb_q3_3a t_q3_3b i_q3_3c lgb_q3_4a t_q3_4b i_q3_4c lgb_q3_5a t_q3_5b i_q3_5c lgb_q3_6_1a t_q3_6_1b i_q3_6_1c lgb_q3_6_2a t_q3_6_2b i_q3_6_2c lgb_q3_7a t_q3_7b i_q3_7c lgb_q3_8_1 lgb_q3_8_2 t_q3_9 i_q3_9 t_q3_10"
global order_d4 "lgb_q4_1_1a t_q4_1_1b i_q4_1_1c lgb_q4_1_2a t_q4_1_2b i_q4_1_2c lgb_q4_1_3a t_q4_1_3b i_q4_1_3c lgb_q4_2 lgb_q4_3a t_q4_3b i_q4_3c lgb_q4_4a t_q4_4b i_q4_4c lgb_q4_5a t_q4_5b i_q4_5c lgb_q4_6a t_q4_6b i_q4_6c lgb_q4_7a t_q4_7b i_q4_7c lgb_q4_8a t_q4_8b i_q4_8c lgb_q4_9a t_q4_9b i_q4_9c i_q4_10a i_q4_10b i_q4_11 t_q4_12 i_q4_12 t_q4_13 lgb_q4_14 t_q4_14 i_q4_14"
global order_d5 "lgb_q5_1 t_q5_1 i_q5_1 lgb_q5_2 t_q5_2 i_q5_2 lgb_q5_3 t_q5_3 i_q5_3 lgb_q5_4a t_q5_4b i_q5_4c lgb_q5_5a t_q5_5b i_q5_5c lgb_q5_6 lgb_q5_7 lgb_q5_8 lgb_q5_9 lgb_q5_10 lgb_q5_11 lgb_q5_12 i_q5_13 lgb_q5_14 t_q5_14 lgb_q5_15a t_q5_15b i_q5_15c lgb_q5_16a t_q5_16b i_q5_16c"
global order_d6 "lgb_q6_1_1a t_q6_1_1b i_q6_1_1c lgb_q6_2_2a t_q6_2_2b i_q6_2_2c lgb_q6_3_3a t_q6_3_3b i_q6_3_3c lgb_q6_4_4a t_q6_4_4b i_q6_4_4c lgb_q6_5_1 t_q6_5_1 i_q6_5_1 lgb_q6_5_2 t_q6_5_2 i_q6_5_2 lgb_q6_5_3 t_q6_5_3 i_q6_5_3 lgb_q6_5_4 t_q6_5_4 i_q6_5_4 lgb_q6_6_1 t_q6_6_1 i_q6_6_1 lgb_q6_6_2 t_q6_6_2 i_q6_6_2 lgb_q6_6_3 t_q6_6_3 i_q6_6_3"

order country countrycode region_dec region incomegroup_fy24 fcs_fy24 lending_cat pop_size legal_trad level_inclusive data_collect $order_d1 $order_d2 $order_d3 $order_d4 $order_d5 $order_d6

* original indicators
global d1 "lgb_q1_1a t_q1_1b i_q1_1c lgb_q1_2 lgb_q1_3 lgb_q1_4a t_q1_4b i_q1_4c t_q1_5 t_q1_6"
global d2 "lgb_q2_1a t_q2_1b i_q2_1c lgb_q2_2a t_q2_2b i_q2_2c lgb_q2_3a t_q2_3b i_q2_3c lgb_q2_4 lgb_q2_5 lgb_q2_6 lgb_q2_7 t_q2_8"
global d3 "lgb_q3_1_1a t_q3_1_1b i_q3_1_1c lgb_q3_1_2a t_q3_1_2b i_q3_1_2c lgb_q3_2_1a t_q3_2_1b i_q3_2_1c lgb_q3_2_2a t_q3_2_2b i_q3_2_2c lgb_q3_3a t_q3_3b i_q3_3c lgb_q3_4a t_q3_4b i_q3_4c lgb_q3_5a t_q3_5b i_q3_5c lgb_q3_6_1a t_q3_6_1b i_q3_6_1c lgb_q3_6_2a t_q3_6_2b i_q3_6_2c lgb_q3_7a t_q3_7b i_q3_7c lgb_q3_8_1 lgb_q3_8_2 t_q3_9 t_q3_10"
global d4 "lgb_q4_1_1a t_q4_1_1b i_q4_1_1c lgb_q4_1_2a t_q4_1_2b i_q4_1_2c lgb_q4_1_3a t_q4_1_3b i_q4_1_3c lgb_q4_2 lgb_q4_3a t_q4_3b i_q4_3c lgb_q4_4a t_q4_4b i_q4_4c lgb_q4_5a t_q4_5b i_q4_5c lgb_q4_6a t_q4_6b i_q4_6c lgb_q4_7a t_q4_7b i_q4_7c lgb_q4_8a t_q4_8b i_q4_8c lgb_q4_9a t_q4_9b i_q4_9c i_q4_10a i_q4_10b i_q4_11 t_q4_12 t_q4_13 lgb_q4_14"
global d5 "lgb_q5_1 lgb_q5_2 lgb_q5_3 lgb_q5_4a t_q5_4b i_q5_4c lgb_q5_5a t_q5_5b i_q5_5c lgb_q5_6 lgb_q5_7 lgb_q5_8 lgb_q5_9 lgb_q5_10 lgb_q5_11 lgb_q5_12 i_q5_13 lgb_q5_14 lgb_q5_15a t_q5_15b i_q5_15c lgb_q5_16a t_q5_16b i_q5_16c"
global d6 "lgb_q6_1_1a t_q6_1_1b i_q6_1_1c lgb_q6_2_2a t_q6_2_2b i_q6_2_2c lgb_q6_3_3a t_q6_3_3b i_q6_3_3c lgb_q6_4_4a t_q6_4_4b i_q6_4_4c lgb_q6_5_1 lgb_q6_5_2 lgb_q6_5_3 lgb_q6_5_4 lgb_q6_6_1 lgb_q6_6_2 lgb_q6_6_3"

global lgb_group "q1_1a q1_2 q1_3 q1_4a q2_1a q2_2a q2_3a q2_4 q2_5 q2_6 q2_7 q3_1_1a q3_1_2a q3_2_1a q3_2_2a q3_3a q3_4a q3_5a q3_6_1a q3_6_2a q3_7a q3_8_1 q3_8_2 q4_1_1a q4_1_2a q4_1_3a q4_2 q4_3a q4_4a q4_5a q4_6a q4_7a q4_8a q4_9a q4_14 q5_1 q5_2 q5_3 q5_4a q5_5a q5_6 q5_7 q5_8 q5_9 q5_10 q5_11 q5_12 q5_14 q5_15a q5_16a q6_1_1a q6_2_2a q6_3_3a q6_4_4a q6_5_1 q6_5_2 q6_5_3 q6_5_4 q6_6_1 q6_6_2 q6_6_3"
global t_group "q1_1b q1_4b q1_5 q1_6 q2_1b q2_2b q2_3b q2_8 q3_1_1b q3_1_2b q3_2_1b q3_2_2b q3_3b q3_4b q3_5b q3_6_1b q3_6_2b q3_7b q3_9 q3_10 q4_1_1b q4_1_2b q4_1_3b q4_3b q4_4b q4_5b q4_6b q4_7b q4_8b q4_9b q4_12 q4_13 q5_4b q5_5b q5_15b q5_16b q6_1_1b q6_2_2b q6_3_3b q6_4_4b"
global i_group "q1_1c q1_4c q2_1c q2_2c q2_3c q3_1_1c q3_1_2c q3_2_1c q3_2_2c q3_3c q3_4c q3_5c q3_6_1c q3_6_2c q3_7c q4_1_1c q4_1_2c q4_1_3c q4_3c q4_4c q4_5c q4_6c q4_7c q4_8c q4_9c q4_10a q4_10b q4_11 q5_4c q5_5c q5_13 q5_15c q5_16c q6_1_1c q6_2_2c q6_3_3c q6_4_4c"

foreach x in $lgb_group{
	clonevar lgb2_`x' = lgb_`x'
	rename lgb2_`x' all_`x'
}
foreach x in $t_group{
	clonevar t2_`x' = t_`x'
	rename t2_`x' all_`x'
}
foreach x in $i_group{
	clonevar i2_`x' = i_`x'
	rename i2_`x' all_`x'
}

save "$output_\EQOSOGI_final_database.dta", replace
